@@ -90,6 +90,9 @@ from .docker_util import (
     docker_rm,
     get_docker_container_id,
     get_docker_container_ip,
+    get_docker_hostname,
+    get_docker_preferred_network_name,
+    is_docker_user_defined_network,
 )
 
 from .ansible_util import (
@@ -430,6 +433,7 @@ def generate_pip_install(pip, command, packages=None, constraints=None, use_cons
     """
     constraints = constraints or os.path.join(ANSIBLE_TEST_DATA_ROOT, 'requirements', 'constraints.txt')
     requirements = os.path.join(ANSIBLE_TEST_DATA_ROOT, 'requirements', '%s.txt' % ('%s.%s' % (command, context) if context else command))
+    content_constraints = None
 
     options = []
 
@@ -448,6 +452,8 @@ def generate_pip_install(pip, command, packages=None, constraints=None, use_cons
         if os.path.exists(requirements) and os.path.getsize(requirements):
             options += ['-r', requirements]
 
+        content_constraints = os.path.join(data_context().content.unit_path, 'constraints.txt')
+
     if command in ('integration', 'windows-integration', 'network-integration'):
         requirements = os.path.join(data_context().content.integration_path, 'requirements.txt')
 
@@ -459,6 +465,11 @@ def generate_pip_install(pip, command, packages=None, constraints=None, use_cons
         if os.path.exists(requirements) and os.path.getsize(requirements):
             options += ['-r', requirements]
 
+        content_constraints = os.path.join(data_context().content.integration_path, 'constraints.txt')
+
+    if command.startswith('integration.cloud.'):
+        content_constraints = os.path.join(data_context().content.integration_path, 'constraints.txt')
+
     if packages:
         options += packages
 
@@ -466,6 +477,10 @@ def generate_pip_install(pip, command, packages=None, constraints=None, use_cons
         return None
 
     if use_constraints:
+        if content_constraints and os.path.exists(content_constraints) and os.path.getsize(content_constraints):
+            # listing content constraints first gives them priority over constraints provided by ansible-test
+            options.extend(['-c', content_constraints])
+
         options.extend(['-c', constraints])
 
     return pip + ['install', '--disable-pip-version-check'] + options
@@ -1243,9 +1258,7 @@ def start_httptester(args):
 
     container_id = get_docker_container_id()
 
-    if container_id:
-        display.info('Running in docker container: %s' % container_id, verbosity=1)
-    else:
+    if not container_id:
         for item in ports:
             item['localhost'] = get_available_port()
 
@@ -1257,7 +1270,7 @@ def start_httptester(args):
         container_host = get_docker_container_ip(args, httptester_id)
         display.info('Found httptester container address: %s' % container_host, verbosity=1)
     else:
-        container_host = 'localhost'
+        container_host = get_docker_hostname()
 
     ssh_options = []
 
@@ -1281,6 +1294,13 @@ def run_httptester(args, ports=None):
         for localhost_port, container_port in ports.items():
             options += ['-p', '%d:%d' % (localhost_port, container_port)]
 
+    network = get_docker_preferred_network_name(args)
+
+    if is_docker_user_defined_network(network):
+        # network-scoped aliases are only supported for containers in user defined networks
+        for alias in HTTPTESTER_HOSTS:
+            options.extend(['--network-alias', alias])
+
     httptester_id = docker_run(args, args.httptester, options=options)[0]
 
     if args.explain:
